package org.pvv.gnapplet;

import android.util.Log;

/**
 * Base class for request handlers.
 *
 * @author Håvard Wigtil
 */
public abstract class AbstractRequestHandler {

    /** Request instance. */
    private GnbusRequest request;

    /** Tag for logging. Set as a normal member so that extending classes
        can provide their own tag for methods in this class. */
    private String loggerTag;

    /**
     * Create a new instance with request set.
     *
     * @param request The request object
     * @param loggerTag Tag to use for logging, should be the tag of the class extending this class
     */
    protected AbstractRequestHandler(GnbusRequest request, String loggerTag) {
        this.request = request;
        this.loggerTag = loggerTag;
    }

    /**
     * Get the request object.
     *
     * @return Request object
     */
    protected GnbusRequest getRequest() {
        return request;
    }

    /**
     * Create a response object, based on the request.
     *
     * @return Response object
     */
    public abstract GnbusResponse createResponse();

    /**
     * Create an error response for unsupported command.
     *
     * @return Response object with NOTSUPPORTED error code
     */
    protected GnbusResponse handleUnsupportedCommand() {
        Log.w(loggerTag, String.format("Command %d for type %d not supported", request.getCommand(), request.getType()));
        return GnbusResponse.createErrorResponse(request.getType(),
                                                 request.getCommand(),
                                                 GnError.NOTSUPPORTED);

    }

}
