package org.pvv.gnapplet;

import android.app.Service;
import android.bluetooth.BluetoothServerSocket;
import android.bluetooth.BluetoothSocket;
import android.util.Log;

import java.io.IOException;

/**
 * Thread for handling Bluetooth communications.
 */
// Should handlerThread be used instead?
public class ConnectorThread extends Thread {

    private static final String TAG = "Gnapplet.ConnectorThread";

    /** The service instance that launched this thread. */
    private Service service;

    private BluetoothServerSocket serverSocket;

    public ConnectorThread(BluetoothServerSocket serverSocket, Service service) {
        this.serverSocket = serverSocket;
        this.service = service;
    }

    @Override
    public void run() {
        Log.i(TAG, "Started ConnectorThread, listening for incoming connections");

        // Loop until server socket is closed
        BluetoothSocket socket;
        while (true) {
            try {
                Log.i(TAG, "Waiting for connection...");
                socket = serverSocket.accept();
                Log.d(TAG, "Accepted connection");
            } catch (IOException e) {
                Log.d(TAG, "IOException from server socket, exiting loop", e);
                break;
            }

            // If a connection was accepted
            if (socket != null) {
                RequestThread rt = new RequestThread(socket, service);
                rt.start();
            }

        }

    }

    /**
     * Stop listening for incoming connections. This will terminate the thread.
     */
    public void cancel() {
        try {
            serverSocket.close();
        } catch (IOException e) {
            Log.d(TAG, "Exception on thread close");
        }
    }

}
