package org.pvv.gnapplet;

/**
 * Error codes for the gnbus protocol. Copied from error.h in Gnokii 0.6.30.
 */
public enum GnError {
	/* General codes */
	NONE,                /* No error. */
	FAILED,			/* Command failed. */
	UNKNOWNMODEL,		/* Model specified isn't known/supported. */
	INVALIDSECURITYCODE,	/* Invalid Security code. */
	INTERNALERROR,		/* Problem occured internal to model specific code. */
	NOTIMPLEMENTED,		/* Command called isn't implemented in model. */
	NOTSUPPORTED,		/* Function not supported by the phone */
	USERCANCELED,		/* User aborted the action. */
	UNKNOWN,			/* Unknown error - well better than nothing!! */
	MEMORYFULL,		/* The specified memory is full. */

	/* Statemachine */
	NOLINK,			/* Couldn't establish link with phone. */
	TIMEOUT,			/* Command timed out. */
	TRYAGAIN,		/* Try again. */
	WAITING,			/* Waiting for the next part of the message. */
	NOTREADY,		/* Device not ready. */
	BUSY,			/* Command is still being executed. */

	/* Locations */
	INVALIDLOCATION,		/* The given memory location has not valid location. */
	INVALIDMEMORYTYPE,	/* Invalid type of memory. */
	EMPTYLOCATION,		/* The given location is empty. */

	/* Format */
	ENTRYTOOLONG, 		/* The given entry is too long */
	WRONGDATAFORMAT,		/* Data format is not valid */
	INVALIDSIZE,		/* Wrong size of the object */

	/* The following are here in anticipation of data call requirements. */
	LINEBUSY,		/* Outgoing call requested reported line busy */
	NOCARRIER,		/* No Carrier error during data call setup ? */

	/* The following value signals the current frame is unhandled */
	UNHANDLEDFRAME,		/* The current frame isn't handled by the incoming function */
	UNSOLICITED,		/* Unsolicited message received. */

	/* Other */
	NONEWCBRECEIVED,		/* Attempt to read CB when no new CB received */
	SIMPROBLEM,		/* SIM card missing or damaged */
	CODEREQUIRED,		/* PIN or PUK code required */
	NOTAVAILABLE,		/* The requested information is not available */

	/* Config */
	NOCONFIG,		/* Config file cannot be found */
	NOPHONE,			/* Either global or given phone section cannot be found */
	NOLOG,			/* Incorrect logging section configuration */
	NOMODEL,			/* No phone model specified */
	NOPORT,			/* No port specified */
	NOCONNECTION,		/* No connection type specified */
	LOCKED,			/* Device is locked and cannot unlock */

	ASYNC			/* The actual response will be sent asynchronously */
}
