package org.pvv.gnapplet;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.util.Log;
import android.view.View;
import android.widget.ToggleButton;


public class GnappletActivity extends Activity
{
    private static String TAG = "Gnapplet.Activity";

    private static int REQUEST_ENABLE_BT = 1;

    /** Service binding status. */
    private boolean bound = false;

    /** Service instance. */
    private GnappletService gnappletService;

    private ToggleButton toggle;

    private void setupBluetoothService() {

        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();

        if (!adapter.isEnabled()) {
            Intent enableBtIntent = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
            startActivityForResult(enableBtIntent, REQUEST_ENABLE_BT);
        } else {
            startBluetoothService();
        }
    }

    private void startBluetoothService()
    {
        Intent i = new Intent(this, GnappletService.class);
        startService(i);
    }

    private void stopBluetoothService() {
        Intent i = new Intent(this, GnappletService.class);
        stopService(i);
    }

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        Log.d(TAG, "Activity onCreate");
        super.onCreate(savedInstanceState);

        // Must initialize view before manipulating widgets
        setContentView(R.layout.main);

        // TODO Check for Bluetooth hardware and disable toggle if not present

        toggle = (ToggleButton)findViewById(R.id.toggle_button);
        Log.d(TAG, "Toggle: " + toggle);
        toggle.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                Log.d(TAG, "Toggle clicked");
                // Perform action on clicks
                if (toggle.isChecked()) {
                    setupBluetoothService();
                } else {
                    stopBluetoothService();
                }
            }
        });

    }

    @Override
    protected void onStart() {
        super.onStart();
        Log.d(TAG, "Binding to service");
        Intent intent = new Intent(this, GnappletService.class);
        bindService(intent, serviceConnection, Context.BIND_AUTO_CREATE);
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (bound) {
            Log.d(TAG, "Unbinding service");
            unbindService(serviceConnection);
            bound = false;
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        Log.d(TAG, "onResume");

        boolean running = gnappletService != null && gnappletService.isRunning();
        toggle.setChecked(running);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == REQUEST_ENABLE_BT)
        {
            if (resultCode == RESULT_OK) {
                startBluetoothService();
            }
        }
    }

    /**
     * Callbacks for service binding
     */
    private ServiceConnection serviceConnection = new ServiceConnection() {
        public void onServiceConnected(ComponentName className, IBinder service) {
            Log.d(TAG, "Got service bound callback");
            GnappletService.GnappletBinder binder = (GnappletService.GnappletBinder) service;
            gnappletService = binder.getService();
            bound = true;
            toggle.setChecked(gnappletService.isRunning());
        }

        public void onServiceDisconnected(ComponentName className) {
            bound = false;
            gnappletService = null;
        }
    };

}
