package org.pvv.gnapplet;

import android.app.Notification;
import android.app.PendingIntent;
import android.app.Service;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothServerSocket;
import android.content.Intent;
import android.os.Binder;
import android.os.IBinder;
import android.util.Log;

import java.io.IOException;
import java.util.UUID;

/**
 * Service for Bluetooth communication and listening and responding to events.
 */
public class GnappletService extends Service {

    private static String TAG = "Gnapplet.Service";

    /** 128-bit UUID for service. This is the same UUID as for the Symbian Gnapplet. */
    private static UUID GNAPPLET_UUID = java.util.UUID.fromString("0d755dee-9493-11dc-8314-0800200c9a66");

    /** Binder instance for service. */
    private GnappletBinder binder = new GnappletBinder();

    private BluetoothServerSocket serverSocket = null;

    /** Thread that handles connections. */
    private ConnectorThread connector;

    /** Flag for service status. */
    private boolean running = false;

    @Override
    public void onCreate() {
        super.onCreate();

        Log.d(TAG, "onCreate");

    }

    @Override
    public IBinder onBind(Intent intent) {
        return binder;
    }

    /**
     * Start service to run in the background.
     *
     * @param intent ?
     * @param flags ?
     * @param startId ?
     * @return ?
     */
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        super.onStartCommand(intent, flags, startId);  // What does super do?


        Log.d(TAG, "onStartCommand");

        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();

        try {
            serverSocket = adapter.listenUsingRfcommWithServiceRecord ("gnapplet", GNAPPLET_UUID);
            Log.i(TAG, "Created server socket");
            connector = new ConnectorThread(serverSocket, this);
            connector.start();
        } catch (IOException e) {
            Log.e(TAG, "Exception setting up Bluetooth server socket", e);
            // Are there better ways to handle this?
            throw new RuntimeException("Failed to set up Bluetooth server socket", e);
        }
        running = true;



        // Set up foreground service and get notification icon
        Notification notification = new Notification(R.drawable.laptop, "Gnapplet", 0);
        Intent notificationIntent = new Intent(this, GnappletActivity.class);
        PendingIntent pendingIntent = PendingIntent.getActivity(this, 0, notificationIntent, 0);
        notification.setLatestEventInfo(this, getText(R.string.notification_title), getText(R.string.notification_message), pendingIntent);
        startForeground(0xbeef, notification);

        // Restart service if it is killed
        return Service.START_STICKY;
    }

    /**
     * Clean up resources when  service stops.
     */
    @Override
    public void onDestroy() {
        running = false;
        Log.d(TAG, "Cleaning up on exit");
        if (serverSocket != null)
        {
            Log.d(TAG, "Stopping server socket");
            try {
                serverSocket.close();
            } catch (IOException e) {
                Log.w(TAG, "Exception when closing server socket", e);
            }
        }

        if (connector != null && connector.isAlive())
        {
            // TODO Is this enough to clean up if there's communication in progress?
            connector.cancel();
        }
    }

    /**
     * Check if service is running.
     *
     * @return <code>true</code> if service is running
     */
    public boolean isRunning() {
        return running;
    }

    /**
     * Binder implementation for GnappletService.
     */
    public class GnappletBinder extends Binder {

        /**
         * Get service instance.
         *
         * @return The service
         */
        public GnappletService getService() {
            return GnappletService.this;
        }
    }
}
