package org.pvv.gnapplet;

import java.util.Arrays;

/**
 * Common base class for Gnapplet request and response messages.
 */
public class GnbusProtocolMessage {

    protected byte type;

    protected short command;

    protected byte[] data;

    protected GnbusProtocolMessage(byte type, short command, byte[] data) {
        this.type = type;
        this.command = command;
        this.data = data;
    }

    public byte getType() {
        return type;
    }

    public short getCommand() {
        return command;
    }

    /**
     * Generate checksum bytes for a Gnapplet message. The last two bytes of the array are used as
     * the seed values for the checksum, and will not be included in the checksum.
     *
     * @param data Data to create checksum for
     * @return Checksum bytes
     */
    public static byte[] generateChecksumBytes(final byte[] data) {
        // Sanity check
        if (data.length < 3) {
            throw new IllegalArgumentException("Array must have at least 3 elements to generate a checksum");
        }

        int check_size = data.length - 2;
        byte[] checksum = { data[check_size], data[check_size + 1]};
        byte check_index = 0;
        for (int i = 0; i < check_size; i++) {
            checksum[check_index] ^= data[i];
            check_index ^= 1; // Flip checksum index between 0 and 1
        }

        return checksum;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append("{type=").append(type);
        sb.append(", command=").append(command);
        sb.append(", data=").append(Arrays.toString(data)).append('}');
        return sb.toString();
    }
}
