package org.pvv.gnapplet;

/**
 * Class for request data sent from Gnokii.
 */
public class GnbusRequest extends GnbusProtocolMessage {

    private GnbusRequest(byte type, short command, byte[] data) {
        super(type, command, data);
    }

    /**
     * Parse a GnbusRequest from raw data.
     *
     * @param raw Raw data for request
     * @return Request instance
     * @throws IllegalArgumentException If input could not be parsed as a GnbusRequest
     */
    public static GnbusRequest parse(byte[] raw) {
        // Minimum length for a message is 8 bytes without a command
        // All known messages include a command, so this is included in the length check
        if (raw.length < 10) {
            throw new IllegalArgumentException("Input must be at least 10 bytes long");
        }
        if (raw[0] != Constants.MAGIC_BYTE) {
            throw new IllegalArgumentException("Input does not start with magic byte");
        }

        byte[] checksum = generateChecksumBytes(raw);

        if (checksum[0] != 0 || checksum[1] != 0) {
            throw new IllegalArgumentException(String.format("Input has incorrect checksum, got bytes %02x and %02x",
                                                             checksum[0], checksum[1]));
        }

        byte msgType = raw[4];

        short msgCommand = (short)(raw[6] * 256);
        msgCommand += (short)raw[7];

        int msgSize = raw[2] * 256 + raw[3] - 2;

        byte[] msg = new byte[msgSize];

        System.arraycopy(raw, 8, msg, 0, msgSize);

        return new GnbusRequest(msgType, msgCommand, msg);
    }

}
