package org.pvv.gnapplet;

import android.app.Service;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.BatteryManager;

/**
 * Handler for power info requests.
 *
 * @author Håvard Wigtil
 */
public class PowerRequestHandler extends AbstractRequestHandler {

    /** Logger tag. */
    private static final String TAG = "Gnapplet.PowerRequestHandler";

    /** Parent service instance. */
    private Service service;

    /**
     * Create a new instance.
     *
     * @param request Request object
     * @param service Parent service
     */
    public PowerRequestHandler(GnbusRequest request, Service service) {
        super(request, TAG);
        this.service = service;
    }

    /**
     * Create a power info response.
     *
     * @return Response object
     */
    @Override
    public GnbusResponse createResponse() {
        switch (getRequest().getCommand()) {
            case Constants.GNAPPLET_MSG_POWER_INFO_REQ:
                return handlePowerInfo();

            default:
                return handleUnsupportedCommand();
        }

    }

    private GnbusResponse handlePowerInfo() {

        Intent i = service.registerReceiver(null, new IntentFilter(Intent.ACTION_BATTERY_CHANGED));

        int level = i.getIntExtra(BatteryManager.EXTRA_LEVEL, 0);
        int scale = i.getIntExtra(BatteryManager.EXTRA_SCALE, 100);
        byte percent = (byte)((level / scale) * 100);

        int plugged = i.getIntExtra(BatteryManager.EXTRA_PLUGGED, -1);
        byte source = 0;
        if (plugged == 0) {
            // Battery power
            source = 2;
        } else if (plugged != -1)
        {
            // External power source
            source = 1;
        }

        return GnbusResponse.createPowerResponse(percent, source);
    }
}
